"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.OpenAiConfigSchema = void 0;
const joi_1 = __importDefault(require("joi"));
const openai_1 = __importDefault(require("openai"));
const ai_client_1 = require("../ai_client");
class OpenAiClient extends ai_client_1.AiClient {
    client;
    parameters;
    constructor(config) {
        super();
        this.client = new openai_1.default({ organization: config.connection.orgId, apiKey: config.connection.apiKey });
        this.parameters = config.parameters;
    }
    async sendMessagesToAi(messages) {
        const completion = await this.client.chat.completions.create({
            messages,
            model: this.parameters?.model || 'gpt-3.5-turbo',
            top_p: this.parameters?.topP,
            temperature: this.parameters?.temperature,
        });
        return { content: completion.choices[0].message.content || undefined };
    }
}
exports.default = OpenAiClient;
exports.OpenAiConfigSchema = joi_1.default.object({
    connection: joi_1.default.object({
        orgId: joi_1.default.string().required(),
        apiKey: joi_1.default.string().required(),
    }).required(),
    parameters: joi_1.default.object({
        model: joi_1.default.string(),
        temperature: joi_1.default.number().min(0).max(1).default(0.5),
        topP: joi_1.default.number().min(0).max(1).default(1),
    })
});
