"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RESPONSE_FORMATS = void 0;
exports.getChatRoute = getChatRoute;
const boom_1 = require("@hapi/boom");
const moment_1 = __importDefault(require("moment/moment"));
// @ts-ignore
const audited_route_handler_1 = require("../../../../src/siren_core_plugins/siren_audit/server/audited_route_handler");
// @ts-ignore
const constants_1 = require("../../../../src/siren_core_plugins/siren_audit/common/constants");
const types_1 = require("../../common/types");
const ai_client_1 = require("../ai_client");
const register_ui_contexts_1 = require("../setup/register_ui_contexts");
const route_utils_1 = require("./route_utils");
exports.RESPONSE_FORMATS = {
    text: '',
    html: 'All of your responses should be returned as HTML snippets and must start with <div>'
};
function getChatRoute(server) {
    const provider = server.config().get('siren-ai.provider');
    const config = server.config().get(`siren-ai.providerConfig.${provider}`);
    const ai = (0, ai_client_1.getAiClient)(provider, config);
    return {
        path: '/api/ai/chat',
        method: 'POST',
        options: {
            pre: [{ method: (0, route_utils_1.isRequestAllowed)(register_ui_contexts_1.SirenAiContexts.LLM_ACCESES_PERMISSION) }]
        },
        handler: (0, audited_route_handler_1.auditedRouteHandler)(constants_1.LOGGED_TYPES.LLMPrompt, async function (req) {
            if (!req.payload.messages) {
                return (0, boom_1.badRequest)('Body must include a "messages" attribute');
            }
            const responseFormatText = exports.RESPONSE_FORMATS[req.payload.responseFormat || 'text'];
            const structuredMessages = [
                {
                    role: 'system',
                    // eslint-disable-next-line max-len
                    content: `You are a helpful assistant helping an investigator gain insights from data that they are looking through. They may have general questions, or may provide data for you to give your analysis on. You can also use functions and tools to assist the user with tasks. If asked to change a node property, look through tools and functions to assist.${responseFormatText}`
                },
                ...req.payload.messages.map(toAiChatMessage)
            ];
            const { content } = await (0, route_utils_1.sendMessagesToAiBoomifyErrors)(ai, structuredMessages);
            return {
                user: types_1.User.Bot,
                content: content || '<no response>',
                timestamp: (0, moment_1.default)().toISOString(),
            };
        })
    };
}
function toAiChatMessage(message) {
    return {
        role: message.user === types_1.User.Bot ? 'assistant' : 'user',
        content: message.content + getAttachmentText(message.attachments)
    };
}
function getAttachmentText(attachments) {
    if (!attachments?.length) {
        return '';
    }
    return '\n\n' + attachments
        .map(attachment => {
        if ((0, types_1.isDocsAttachment)(attachment)) {
            return `Here are the associated documents relating to my above query formatted in JSON:\n${JSON.stringify(attachment.docs)}`;
        }
    })
        .join('\n\n');
}
