"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isRequestAllowed = isRequestAllowed;
exports.sendMessagesToAiBoomifyErrors = sendMessagesToAiBoomifyErrors;
const boom_1 = require("@hapi/boom");
function isRequestAllowed(contextId) {
    return async (request) => {
        const credentials = request.auth.credentials;
        const accessControlPlugin = request.server.plugins.investigate_access_control;
        if (accessControlPlugin) {
            const isAllowed = await accessControlPlugin.isAllowed(credentials, null, ['view'], contextId);
            if (!isAllowed) {
                throw (0, boom_1.forbidden)('Request denied by ACL.');
            }
        }
        return null;
    };
}
async function sendMessagesToAiBoomifyErrors(ai, messages) {
    try {
        return await ai.sendMessagesToAi(messages);
    }
    catch (e) {
        console.error(e);
        throw new boom_1.Boom(e.message, { statusCode: e.status || 500 });
    }
}
